@@ -2,7 +2,9 @@
 from .Enviopack import Enviopack
 from .Auth.Auth import Auth
 from .Quote.Quote import Quote
+from .Pickings.Pickings import Pickings
+from .Orders.Orders import Orders
 
-__version__ = "0.1.0"
+__version__ = "0.4.2"
 __author__ = "Federico Gobea"
 
